import "package:meta/meta.dart";

/// Align some columns (separated by [delimiter]) in [rows] so that 
/// each column is distinct from the others.
///
/// Use [spacesPerTab] to manually set how many spaces it takes to reach 
/// the length of one `\t`. The default works fine for linux.
Iterable<String> tabAlign( {@required List<String> rows, String delimiter = "\t", int spacesPerTab = 8} )
{
//	Create a list of the values of every column in every row of [rows].
	final List<List<String>> rowsToColumns = new List<List<String>>.of(
			rows.map<List<String>>( (String row) => row.split(delimiter) )
		);

//	A list to track the longest [String] pertaining to each column.
	final List<int> longestRowInColumn	   = new List<int>.generate(rowsToColumns[0].length, (int i) => 0);

//	Fill [longestRowInColumn].
	for ( final List<String> row in rowsToColumns )
	{
//		For every column inside of [row].
		for ( int column = 0; column < row.length; ++column )
		{
//			If a particular column's length is longer than the
//			recorded longest, update [longestRowInColumn].
			if ( row[column].length > longestRowInColumn[column] )
			{
				longestRowInColumn[column] = row[column].length;
			}
		}
	}

//	Iterate over [rowsToColumns] again.
//	
//	This time, add `\t`s based on how much shorter a given column is
//	than the longest column in terms of tabs.
	for ( final List<String> row in rowsToColumns )
	{
		for ( int column = 0; column < row.length - 1; ++column )
		{
			final int diff = ( (longestRowInColumn[column] - row[column].length) / spacesPerTab ).round();
			for ( int i = 0; i < diff; ++i )
			{
				row[column] += "\t ";
			}
		}
	}

//  Join the [List] and `return` it.
	return rowsToColumns.map<String>( (List<String> columns) => columns.join(delimiter) );
}
