/// Calculate [Duration] in fractional hours.
/// 
/// A [Duration]'s `inHours` method does not measure out 
/// fractions of an hour. This method converts [d] in minutes 
/// to hours manually, thus preserving the fractions of hours
/// that may be in each one.
double durationExactHours( Duration d )
{
	return ( (d.inSeconds) / 60 ) / 60;
}

/// Return a human-readable version of [Duration] [d].
String durationHumanReadable( Duration d )
{
	final List<String> _durationSplit = d.toString().split(":");
	final String hourString = durationExactHours(d) != 1                ? "hours"   : "hour";
	final String minuteString = (d.inMinutes - (d.inHours * 60)) != 1   ? "minutes" : "minute";
	final String secondString = (d.inSeconds - (d.inMinutes * 60)) != 1 ? "seconds" : "second";

	return "${_durationSplit[0]} $hourString, "
			"${_durationSplit[1]} $minuteString, "
			"${_durationSplit[2].substring(0,2)} $secondString";
}
